searchData={"items":[{"type":"module","title":"Poodle","doc":"Elixir SDK for the Poodle email sending API.\n\nThis module provides a simple and idiomatic Elixir interface for sending\nemails through the Poodle platform. It supports both HTML and plain text\nemails, comprehensive error handling, rate limiting, and asynchronous operations.","ref":"Poodle.html"},{"type":"module","title":"Quick Start - Poodle","doc":"# Set your API key\n    export POODLE_API_KEY=your_api_key_here\n\n    # Send a simple email\n    {:ok, response} = Poodle.send(\n      \"sender@yourdomain.com\",\n      \"recipient@example.com\",\n      \"Hello from Poodle!\",\n      html: \" Welcome!  This is a test email. \",\n      text: \"Welcome! This is a test email.\"\n    )","ref":"Poodle.html#module-quick-start"},{"type":"module","title":"Configuration - Poodle","doc":"The SDK can be configured via environment variables or application config:\n\n    # Environment variables\n    export POODLE_API_KEY=your_api_key\n    export POODLE_BASE_URL=https://api.usepoodle.com\n    export POODLE_TIMEOUT=30000\n    export POODLE_DEBUG=false\n\n    # Or in config/config.exs\n    config :poodle,\n      api_key: \"your_api_key\",\n      base_url: \"https://api.usepoodle.com\",\n      timeout: 30_000,\n      debug: false","ref":"Poodle.html#module-configuration"},{"type":"module","title":"Error Handling - Poodle","doc":"All functions return `{:ok, response}` or `{:error, error}` tuples:\n\n    case Poodle.send(from, to, subject, html: html) do\n      {:ok, response} ->\n        IO.puts(\"Email sent! Message: \" <> response.message)\n\n      {:error, %Poodle.Error{type: :rate_limit_exceeded, retry_after: retry_after}} ->\n        IO.puts(\"Rate limited. Retry after \" <> to_string(retry_after) <> \" seconds\")\n\n      {:error, %Poodle.Error{type: :unauthorized}} ->\n        IO.puts(\"Invalid API key\")\n\n      {:error, error} ->\n        IO.puts(\"Error: \" <> error.message)\n    end","ref":"Poodle.html#module-error-handling"},{"type":"function","title":"Poodle.send/4","doc":"Send an email with HTML and/or text content.","ref":"Poodle.html#send/4"},{"type":"function","title":"Parameters - Poodle.send/4","doc":"- `from` - Sender email address\n- `to` - Recipient email address\n- `subject` - Email subject line\n- `opts` - Options including `:html`, `:text`, `:config`","ref":"Poodle.html#send/4-parameters"},{"type":"function","title":"Examples - Poodle.send/4","doc":"# HTML email\n    {:ok, response} = Poodle.send(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      html: \" Hello World! \"\n    )\n\n    # Text email\n    {:ok, response} = Poodle.send(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      text: \"Hello World!\"\n    )\n\n    # Both HTML and text\n    {:ok, response} = Poodle.send(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      html: \" Hello World! \",\n      text: \"Hello World!\"\n    )\n\n    # With custom config\n    {:ok, response} = Poodle.send(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      html: \" Hello World! \",\n      config: [api_key: \"custom_key\"]\n    )","ref":"Poodle.html#send/4-examples"},{"type":"function","title":"Poodle.send_async/4","doc":"Send an email asynchronously.\n\nReturns a Task that can be awaited for the result.","ref":"Poodle.html#send_async/4"},{"type":"function","title":"Examples - Poodle.send_async/4","doc":"task = Poodle.send_async(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      html: \" Hello World! \"\n    )\n\n    {:ok, response} = Task.await(task)","ref":"Poodle.html#send_async/4-examples"},{"type":"function","title":"Poodle.send_email/3","doc":"Send an email using an Email struct.","ref":"Poodle.html#send_email/3"},{"type":"function","title":"Examples - Poodle.send_email/3","doc":"{:ok, email} = Poodle.Email.new(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      html: \" Hello World! \"\n    )\n\n    {:ok, response} = Poodle.send_email(email)","ref":"Poodle.html#send_email/3-examples"},{"type":"function","title":"Poodle.send_email_async/3","doc":"Send an email using an Email struct asynchronously.","ref":"Poodle.html#send_email_async/3"},{"type":"function","title":"Examples - Poodle.send_email_async/3","doc":"{:ok, email} = Poodle.Email.new(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      html: \" Hello World! \"\n    )\n\n    task = Poodle.send_email_async(email)\n    {:ok, response} = Task.await(task)","ref":"Poodle.html#send_email_async/3-examples"},{"type":"function","title":"Poodle.send_html/5","doc":"Send an HTML email.","ref":"Poodle.html#send_html/5"},{"type":"function","title":"Examples - Poodle.send_html/5","doc":"{:ok, response} = Poodle.send_html(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      \" Hello World!  Welcome to our service! \"\n    )","ref":"Poodle.html#send_html/5-examples"},{"type":"function","title":"Poodle.send_html_async/5","doc":"Send an HTML email asynchronously.","ref":"Poodle.html#send_html_async/5"},{"type":"function","title":"Examples - Poodle.send_html_async/5","doc":"task = Poodle.send_html_async(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      \" Hello World! \"\n    )\n\n    {:ok, response} = Task.await(task)","ref":"Poodle.html#send_html_async/5-examples"},{"type":"function","title":"Poodle.send_text/5","doc":"Send a plain text email.","ref":"Poodle.html#send_text/5"},{"type":"function","title":"Examples - Poodle.send_text/5","doc":"{:ok, response} = Poodle.send_text(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      \"Hello World! Welcome to our service!\"\n    )","ref":"Poodle.html#send_text/5-examples"},{"type":"function","title":"Poodle.send_text_async/5","doc":"Send a plain text email asynchronously.","ref":"Poodle.html#send_text_async/5"},{"type":"function","title":"Examples - Poodle.send_text_async/5","doc":"task = Poodle.send_text_async(\n      \"sender@example.com\",\n      \"recipient@example.com\",\n      \"Welcome!\",\n      \"Hello World!\"\n    )\n\n    {:ok, response} = Task.await(task)","ref":"Poodle.html#send_text_async/5-examples"},{"type":"function","title":"Poodle.validate_config/1","doc":"Validate the current configuration.","ref":"Poodle.html#validate_config/1"},{"type":"function","title":"Examples - Poodle.validate_config/1","doc":"case Poodle.validate_config() do\n      {:ok, config} ->\n        IO.puts(\"Configuration is valid\")\n      {:error, reason} ->\n        IO.puts(\"Configuration error: \" <> reason)\n    end","ref":"Poodle.html#validate_config/1-examples"},{"type":"module","title":"Poodle.Client","doc":"Main client for the Poodle SDK.\n\nProvides high-level functions for sending emails through the Poodle API.","ref":"Poodle.Client.html"},{"type":"function","title":"Poodle.Client.send/4","doc":"Send an email with both HTML and text content.","ref":"Poodle.Client.html#send/4"},{"type":"function","title":"Examples - Poodle.Client.send/4","doc":"iex> Poodle.Client.send(\"from@example.com\", \"to@example.com\", \"Subject\", html: \" Hello \", text: \"Hello\")\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send/4-examples"},{"type":"function","title":"Poodle.Client.send_async/4","doc":"Send an email asynchronously.\n\nReturns a Task that can be awaited for the result.","ref":"Poodle.Client.html#send_async/4"},{"type":"function","title":"Examples - Poodle.Client.send_async/4","doc":"iex> task = Poodle.Client.send_async(\"from@example.com\", \"to@example.com\", \"Subject\", html: \" Hello \")\n    iex> Task.await(task)\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send_async/4-examples"},{"type":"function","title":"Poodle.Client.send_email/3","doc":"Send an email using an Email struct.","ref":"Poodle.Client.html#send_email/3"},{"type":"function","title":"Examples - Poodle.Client.send_email/3","doc":"iex> email = %Poodle.Email{from: \"from@example.com\", to: \"to@example.com\", subject: \"Subject\", html: \" Hello \"}\n    iex> Poodle.Client.send_email(email)\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send_email/3-examples"},{"type":"function","title":"Poodle.Client.send_email_async/3","doc":"Send an email using an Email struct asynchronously.","ref":"Poodle.Client.html#send_email_async/3"},{"type":"function","title":"Examples - Poodle.Client.send_email_async/3","doc":"iex> email = %Poodle.Email{from: \"from@example.com\", to: \"to@example.com\", subject: \"Subject\", html: \" Hello \"}\n    iex> task = Poodle.Client.send_email_async(email)\n    iex> Task.await(task)\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send_email_async/3-examples"},{"type":"function","title":"Poodle.Client.send_html/5","doc":"Send an HTML email.","ref":"Poodle.Client.html#send_html/5"},{"type":"function","title":"Examples - Poodle.Client.send_html/5","doc":"iex> Poodle.Client.send_html(\"from@example.com\", \"to@example.com\", \"Subject\", \" Hello \")\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send_html/5-examples"},{"type":"function","title":"Poodle.Client.send_html_async/5","doc":"Send an HTML email asynchronously.","ref":"Poodle.Client.html#send_html_async/5"},{"type":"function","title":"Examples - Poodle.Client.send_html_async/5","doc":"iex> task = Poodle.Client.send_html_async(\"from@example.com\", \"to@example.com\", \"Subject\", \" Hello \")\n    iex> Task.await(task)\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send_html_async/5-examples"},{"type":"function","title":"Poodle.Client.send_text/5","doc":"Send a plain text email.","ref":"Poodle.Client.html#send_text/5"},{"type":"function","title":"Examples - Poodle.Client.send_text/5","doc":"iex> Poodle.Client.send_text(\"from@example.com\", \"to@example.com\", \"Subject\", \"Hello\")\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send_text/5-examples"},{"type":"function","title":"Poodle.Client.send_text_async/5","doc":"Send a plain text email asynchronously.","ref":"Poodle.Client.html#send_text_async/5"},{"type":"function","title":"Examples - Poodle.Client.send_text_async/5","doc":"iex> task = Poodle.Client.send_text_async(\"from@example.com\", \"to@example.com\", \"Subject\", \"Hello\")\n    iex> Task.await(task)\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.Client.html#send_text_async/5-examples"},{"type":"module","title":"Poodle.Config","doc":"Configuration management for the Poodle SDK.\n\nSupports configuration via environment variables and application config.","ref":"Poodle.Config.html"},{"type":"function","title":"Poodle.Config.get/1","doc":"Get the current configuration.\n\nConfiguration is resolved in the following order:\n1. Explicitly passed options\n2. Application configuration\n3. Environment variables\n4. Default values","ref":"Poodle.Config.html#get/1"},{"type":"function","title":"Examples - Poodle.Config.get/1","doc":"iex> Poodle.Config.get()\n    {:ok, %Poodle.Config{...}}\n\n    iex> Poodle.Config.get(api_key: \"custom_key\")\n    {:ok, %Poodle.Config{api_key: \"custom_key\", ...}}","ref":"Poodle.Config.html#get/1-examples"},{"type":"function","title":"Poodle.Config.get!/1","doc":"Get the current configuration, raising on error.","ref":"Poodle.Config.html#get!/1"},{"type":"function","title":"Examples - Poodle.Config.get!/1","doc":"iex> Poodle.Config.get!()\n    %Poodle.Config{...}","ref":"Poodle.Config.html#get!/1-examples"},{"type":"function","title":"Poodle.Config.max_content_size/0","doc":"Get the maximum content size allowed.","ref":"Poodle.Config.html#max_content_size/0"},{"type":"type","title":"Poodle.Config.t/0","doc":"","ref":"Poodle.Config.html#t:t/0"},{"type":"function","title":"Poodle.Config.validate/1","doc":"Validate configuration.","ref":"Poodle.Config.html#validate/1"},{"type":"function","title":"Examples - Poodle.Config.validate/1","doc":"iex> config = %Poodle.Config{api_key: \"key\", base_url: \"https://api.example.com\"}\n    iex> Poodle.Config.validate(config)\n    :ok","ref":"Poodle.Config.html#validate/1-examples"},{"type":"module","title":"Poodle.Email","doc":"Email struct and validation for the Poodle SDK.","ref":"Poodle.Email.html"},{"type":"function","title":"Poodle.Email.new/4","doc":"Create a new email struct.","ref":"Poodle.Email.html#new/4"},{"type":"function","title":"Examples - Poodle.Email.new/4","doc":"iex> Poodle.Email.new(\"from@example.com\", \"to@example.com\", \"Subject\", html: \" Hello \")\n    {:ok, %Poodle.Email{...}}\n\n    iex> Poodle.Email.new(\"invalid-email\", \"to@example.com\", \"Subject\")\n    {:error, \"Invalid from email address\"}","ref":"Poodle.Email.html#new/4-examples"},{"type":"function","title":"Poodle.Email.new!/4","doc":"Create a new email struct, raising on error.","ref":"Poodle.Email.html#new!/4"},{"type":"function","title":"Examples - Poodle.Email.new!/4","doc":"iex> Poodle.Email.new!(\"from@example.com\", \"to@example.com\", \"Subject\", html: \" Hello \")\n    %Poodle.Email{...}","ref":"Poodle.Email.html#new!/4-examples"},{"type":"type","title":"Poodle.Email.t/0","doc":"","ref":"Poodle.Email.html#t:t/0"},{"type":"function","title":"Poodle.Email.to_map/1","doc":"Convert email struct to a map for API requests.","ref":"Poodle.Email.html#to_map/1"},{"type":"function","title":"Examples - Poodle.Email.to_map/1","doc":"iex> email = %Poodle.Email{from: \"from@example.com\", to: \"to@example.com\", subject: \"Test\", html: \" Hello \"}\n    iex> Poodle.Email.to_map(email)\n    %{from: \"from@example.com\", to: \"to@example.com\", subject: \"Test\", html: \" Hello \"}","ref":"Poodle.Email.html#to_map/1-examples"},{"type":"function","title":"Poodle.Email.validate/1","doc":"Validate an email struct.","ref":"Poodle.Email.html#validate/1"},{"type":"function","title":"Examples - Poodle.Email.validate/1","doc":"iex> email = %Poodle.Email{from: \"from@example.com\", to: \"to@example.com\", subject: \"Test\", html: \" Hello \"}\n    iex> Poodle.Email.validate(email)\n    :ok","ref":"Poodle.Email.html#validate/1-examples"},{"type":"module","title":"Poodle.Error","doc":"Error struct for the Poodle SDK.\n\nProvides structured error information with context and debugging details.","ref":"Poodle.Error.html"},{"type":"function","title":"Poodle.Error.dns_error/2","doc":"Create a new DNS error.","ref":"Poodle.Error.html#dns_error/2"},{"type":"function","title":"Examples - Poodle.Error.dns_error/2","doc":"iex> Poodle.Error.dns_error(\"DNS resolution failed\", %{host: \"api.example.com\"})\n    %Poodle.Error{type: :dns_error, message: \"DNS resolution failed\", details: %{host: \"api.example.com\"}}","ref":"Poodle.Error.html#dns_error/2-examples"},{"type":"type","title":"Poodle.Error.error_type/0","doc":"","ref":"Poodle.Error.html#t:error_type/0"},{"type":"function","title":"Poodle.Error.forbidden/2","doc":"Create a new forbidden error.","ref":"Poodle.Error.html#forbidden/2"},{"type":"function","title":"Examples - Poodle.Error.forbidden/2","doc":"iex> Poodle.Error.forbidden(\"Account suspended\")\n    %Poodle.Error{type: :forbidden, message: \"Account suspended\"}","ref":"Poodle.Error.html#forbidden/2-examples"},{"type":"function","title":"Poodle.Error.from_response/2","doc":"Create an error from HTTP response.","ref":"Poodle.Error.html#from_response/2"},{"type":"function","title":"Examples - Poodle.Error.from_response/2","doc":"iex> Poodle.Error.from_response(401, %{\"message\" => \"Invalid API key\"})\n    %Poodle.Error{type: :unauthorized, message: \"Invalid API key\", status_code: 401}","ref":"Poodle.Error.html#from_response/2-examples"},{"type":"function","title":"Poodle.Error.network_error/2","doc":"Create a new network error.","ref":"Poodle.Error.html#network_error/2"},{"type":"function","title":"Examples - Poodle.Error.network_error/2","doc":"iex> Poodle.Error.network_error(\"Connection failed\")\n    %Poodle.Error{type: :network_error, message: \"Connection failed\"}","ref":"Poodle.Error.html#network_error/2-examples"},{"type":"function","title":"Poodle.Error.payment_required/2","doc":"Create a new payment required error.","ref":"Poodle.Error.html#payment_required/2"},{"type":"function","title":"Examples - Poodle.Error.payment_required/2","doc":"iex> Poodle.Error.payment_required(\"Subscription expired\")\n    %Poodle.Error{type: :payment_required, message: \"Subscription expired\"}","ref":"Poodle.Error.html#payment_required/2-examples"},{"type":"function","title":"Poodle.Error.rate_limit_exceeded/3","doc":"Create a new rate limit exceeded error.","ref":"Poodle.Error.html#rate_limit_exceeded/3"},{"type":"function","title":"Examples - Poodle.Error.rate_limit_exceeded/3","doc":"iex> Poodle.Error.rate_limit_exceeded(\"Rate limit exceeded\", 30)\n    %Poodle.Error{type: :rate_limit_exceeded, message: \"Rate limit exceeded\", retry_after: 30}","ref":"Poodle.Error.html#rate_limit_exceeded/3-examples"},{"type":"function","title":"Poodle.Error.server_error/3","doc":"Create a new server error.","ref":"Poodle.Error.html#server_error/3"},{"type":"function","title":"Examples - Poodle.Error.server_error/3","doc":"iex> Poodle.Error.server_error(\"Internal server error\", 500)\n    %Poodle.Error{type: :server_error, message: \"Internal server error\", status_code: 500}","ref":"Poodle.Error.html#server_error/3-examples"},{"type":"function","title":"Poodle.Error.ssl_error/2","doc":"Create a new SSL error.","ref":"Poodle.Error.html#ssl_error/2"},{"type":"function","title":"Examples - Poodle.Error.ssl_error/2","doc":"iex> Poodle.Error.ssl_error(\"SSL certificate verification failed\")\n    %Poodle.Error{type: :ssl_error, message: \"SSL certificate verification failed\"}","ref":"Poodle.Error.html#ssl_error/2-examples"},{"type":"type","title":"Poodle.Error.t/0","doc":"","ref":"Poodle.Error.html#t:t/0"},{"type":"function","title":"Poodle.Error.timeout/2","doc":"Create a new timeout error.","ref":"Poodle.Error.html#timeout/2"},{"type":"function","title":"Examples - Poodle.Error.timeout/2","doc":"iex> Poodle.Error.timeout(\"Request timeout\", %{timeout: 30000})\n    %Poodle.Error{type: :timeout, message: \"Request timeout\", details: %{timeout: 30000}}","ref":"Poodle.Error.html#timeout/2-examples"},{"type":"function","title":"Poodle.Error.unauthorized/2","doc":"Create a new unauthorized error.","ref":"Poodle.Error.html#unauthorized/2"},{"type":"function","title":"Examples - Poodle.Error.unauthorized/2","doc":"iex> Poodle.Error.unauthorized(\"Invalid API key\")\n    %Poodle.Error{type: :unauthorized, message: \"Invalid API key\"}","ref":"Poodle.Error.html#unauthorized/2-examples"},{"type":"function","title":"Poodle.Error.unprocessable_entity/2","doc":"Create a new unprocessable entity error.","ref":"Poodle.Error.html#unprocessable_entity/2"},{"type":"function","title":"Examples - Poodle.Error.unprocessable_entity/2","doc":"iex> Poodle.Error.unprocessable_entity(\"Invalid data format\")\n    %Poodle.Error{type: :unprocessable_entity, message: \"Invalid data format\", status_code: 422}","ref":"Poodle.Error.html#unprocessable_entity/2-examples"},{"type":"function","title":"Poodle.Error.validation_error/2","doc":"Create a new validation error.","ref":"Poodle.Error.html#validation_error/2"},{"type":"function","title":"Examples - Poodle.Error.validation_error/2","doc":"iex> Poodle.Error.validation_error(\"Invalid email address\", %{field: \"from\"})\n    %Poodle.Error{type: :validation_error, message: \"Invalid email address\", details: %{field: \"from\"}}","ref":"Poodle.Error.html#validation_error/2-examples"},{"type":"module","title":"Poodle.HTTP.Client","doc":"HTTP client for the Poodle SDK.\n\nHandles HTTP requests to the Poodle API with proper error handling,\nauthentication, and rate limiting.","ref":"Poodle.HTTP.Client.html"},{"type":"function","title":"Poodle.HTTP.Client.post/4","doc":"Send a POST request to the Poodle API.","ref":"Poodle.HTTP.Client.html#post/4"},{"type":"function","title":"Examples - Poodle.HTTP.Client.post/4","doc":"iex> config = %Poodle.Config{api_key: \"key\", base_url: \"https://api.example.com\"}\n    iex> data = %{from: \"from@example.com\", to: \"to@example.com\", subject: \"Test\"}\n    iex> Poodle.HTTP.Client.post(config, \"/v1/send-email\", data)\n    {:ok, %Poodle.Response{...}}","ref":"Poodle.HTTP.Client.html#post/4-examples"},{"type":"module","title":"Poodle.RateLimit","doc":"Rate limit information for the Poodle SDK.\n\nHandles parsing and exposing rate limit data from API responses.","ref":"Poodle.RateLimit.html"},{"type":"function","title":"Poodle.RateLimit.exceeded?/1","doc":"Check if rate limit is exceeded.","ref":"Poodle.RateLimit.html#exceeded?/1"},{"type":"function","title":"Examples - Poodle.RateLimit.exceeded?/1","doc":"iex> rate_limit = %Poodle.RateLimit{remaining: 0}\n    iex> Poodle.RateLimit.exceeded?(rate_limit)\n    true\n\n    iex> rate_limit = %Poodle.RateLimit{remaining: 1}\n    iex> Poodle.RateLimit.exceeded?(rate_limit)\n    false","ref":"Poodle.RateLimit.html#exceeded?/1-examples"},{"type":"function","title":"Poodle.RateLimit.from_headers/1","doc":"Parse rate limit information from HTTP headers.","ref":"Poodle.RateLimit.html#from_headers/1"},{"type":"function","title":"Examples - Poodle.RateLimit.from_headers/1","doc":"iex> headers = %{\"ratelimit-limit\" => \"2\", \"ratelimit-remaining\" => \"1\", \"ratelimit-reset\" => \"1640995200\"}\n    iex> Poodle.RateLimit.from_headers(headers)\n    %Poodle.RateLimit{limit: 2, remaining: 1, reset: 1640995200}","ref":"Poodle.RateLimit.html#from_headers/1-examples"},{"type":"type","title":"Poodle.RateLimit.t/0","doc":"","ref":"Poodle.RateLimit.html#t:t/0"},{"type":"function","title":"Poodle.RateLimit.time_until_reset/1","doc":"Get the time until rate limit resets.","ref":"Poodle.RateLimit.html#time_until_reset/1"},{"type":"function","title":"Examples - Poodle.RateLimit.time_until_reset/1","doc":"iex> rate_limit = %Poodle.RateLimit{reset: 1640995200}\n    iex> Poodle.RateLimit.time_until_reset(rate_limit)\n    300  # seconds until reset","ref":"Poodle.RateLimit.html#time_until_reset/1-examples"},{"type":"function","title":"Poodle.RateLimit.wait_time/1","doc":"Get the recommended wait time before retrying.\n\nReturns retry_after if available, otherwise calculates based on reset time.","ref":"Poodle.RateLimit.html#wait_time/1"},{"type":"function","title":"Examples - Poodle.RateLimit.wait_time/1","doc":"iex> rate_limit = %Poodle.RateLimit{retry_after: 30}\n    iex> Poodle.RateLimit.wait_time(rate_limit)\n    30","ref":"Poodle.RateLimit.html#wait_time/1-examples"},{"type":"module","title":"Poodle.Response","doc":"Response struct for the Poodle SDK.\n\nRepresents successful API responses with rate limit information.","ref":"Poodle.Response.html"},{"type":"function","title":"Poodle.Response.message/1","doc":"Get the response message.","ref":"Poodle.Response.html#message/1"},{"type":"function","title":"Examples - Poodle.Response.message/1","doc":"iex> response = %Poodle.Response{message: \"Email queued for sending\"}\n    iex> Poodle.Response.message(response)\n    \"Email queued for sending\"","ref":"Poodle.Response.html#message/1-examples"},{"type":"function","title":"Poodle.Response.new/2","doc":"Create a new response from HTTP response data.","ref":"Poodle.Response.html#new/2"},{"type":"function","title":"Examples - Poodle.Response.new/2","doc":"iex> body = %{\"success\" => true, \"message\" => \"Email queued for sending\"}\n    iex> headers = %{\"ratelimit-remaining\" => \"1\"}\n    iex> Poodle.Response.new(body, headers)\n    %Poodle.Response{success: true, message: \"Email queued for sending\", ...}","ref":"Poodle.Response.html#new/2-examples"},{"type":"function","title":"Poodle.Response.rate_limit/1","doc":"Get rate limit information from the response.","ref":"Poodle.Response.html#rate_limit/1"},{"type":"function","title":"Examples - Poodle.Response.rate_limit/1","doc":"iex> response = %Poodle.Response{rate_limit: %Poodle.RateLimit{remaining: 1}}\n    iex> Poodle.Response.rate_limit(response)\n    %Poodle.RateLimit{remaining: 1}","ref":"Poodle.Response.html#rate_limit/1-examples"},{"type":"function","title":"Poodle.Response.success?/1","doc":"Check if the response indicates success.","ref":"Poodle.Response.html#success?/1"},{"type":"function","title":"Examples - Poodle.Response.success?/1","doc":"iex> response = %Poodle.Response{success: true}\n    iex> Poodle.Response.success?(response)\n    true","ref":"Poodle.Response.html#success?/1-examples"},{"type":"type","title":"Poodle.Response.t/0","doc":"","ref":"Poodle.Response.html#t:t/0"},{"type":"extras","title":"Poodle Elixir SDK","doc":"# Poodle Elixir SDK\n\n[![Hex.pm](https://img.shields.io/hexpm/v/poodle.svg)](https://hex.pm/packages/poodle)\n[![Build Status](https://github.com/usepoodle/poodle-elixir/workflows/CI/badge.svg)](https://github.com/usepoodle/poodle-elixir/actions)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](./LICENSE)\n\nElixir SDK for the Poodle email sending API.","ref":"readme.html"},{"type":"extras","title":"Features - Poodle Elixir SDK","doc":"- 🚀 Simple and intuitive API\n- 📧 HTML and plain text email support\n- 🔒 Comprehensive error handling\n- ⚡ Asynchronous email sending\n- 🛡️ Built-in input validation\n- 📊 Rate limiting support\n- 🔧 Configurable via environment variables\n- 🎯 Pattern-matchable error tuples\n- 📖 Complete documentation and examples\n- ✅ Elixir 1.14+ support","ref":"readme.html#features"},{"type":"extras","title":"Installation - Poodle Elixir SDK","doc":"Add `poodle` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:poodle, \"~> 1.0\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - Poodle Elixir SDK","doc":"","ref":"readme.html#quick-start"},{"type":"extras","title":"1. Set your API key - Poodle Elixir SDK","doc":"```bash\nexport POODLE_API_KEY=your_api_key_here\n```","ref":"readme.html#1-set-your-api-key"},{"type":"extras","title":"2. Send your first email - Poodle Elixir SDK","doc":"```elixir\n# Send an HTML email\n{:ok, response} = Poodle.send_html(\n  \"sender@yourdomain.com\",\n  \"recipient@example.com\",\n  \"Hello from Poodle!\",\n  \" Welcome!  This is a test email. \"\n)\n\nIO.puts(\"Email sent! Message: #{response.message}\")\n```","ref":"readme.html#2-send-your-first-email"},{"type":"extras","title":"Configuration - Poodle Elixir SDK","doc":"The SDK can be configured via environment variables or application config:","ref":"readme.html#configuration"},{"type":"extras","title":"Environment Variables - Poodle Elixir SDK","doc":"```bash\nexport POODLE_API_KEY=your_api_key\nexport POODLE_BASE_URL=https://api.usepoodle.com\nexport POODLE_TIMEOUT=30000\nexport POODLE_DEBUG=false\n```","ref":"readme.html#environment-variables"},{"type":"extras","title":"Application Config - Poodle Elixir SDK","doc":"```elixir\n# config/config.exs\nconfig :poodle,\n  api_key: \"your_api_key\",\n  base_url: \"https://api.usepoodle.com\",\n  timeout: 30_000,\n  debug: false\n```","ref":"readme.html#application-config"},{"type":"extras","title":"Usage Examples - Poodle Elixir SDK","doc":"","ref":"readme.html#usage-examples"},{"type":"extras","title":"Basic Email Sending - Poodle Elixir SDK","doc":"```elixir\n# HTML email\n{:ok, response} = Poodle.send_html(\n  \"sender@example.com\",\n  \"recipient@example.com\",\n  \"Welcome!\",\n  \" Hello World!  Welcome to our service! \"\n)\n\n# Plain text email\n{:ok, response} = Poodle.send_text(\n  \"sender@example.com\",\n  \"recipient@example.com\",\n  \"Welcome!\",\n  \"Hello World! Welcome to our service!\"\n)\n\n# Both HTML and text\n{:ok, response} = Poodle.send(\n  \"sender@example.com\",\n  \"recipient@example.com\",\n  \"Welcome!\",\n  html: \" Hello World! \",\n  text: \"Hello World!\"\n)\n```","ref":"readme.html#basic-email-sending"},{"type":"extras","title":"Using Email Structs - Poodle Elixir SDK","doc":"```elixir\n# Create an email struct\n{:ok, email} = Poodle.Email.new(\n  \"sender@example.com\",\n  \"recipient@example.com\",\n  \"Welcome!\",\n  html: \" Hello World! \",\n  text: \"Hello World!\"\n)\n\n# Send the email\n{:ok, response} = Poodle.send_email(email)\n```","ref":"readme.html#using-email-structs"},{"type":"extras","title":"Asynchronous Sending - Poodle Elixir SDK","doc":"```elixir\n# Send email asynchronously\ntask = Poodle.send_async(\n  \"sender@example.com\",\n  \"recipient@example.com\",\n  \"Welcome!\",\n  html: \" Hello World! \"\n)\n\n# Wait for result\n{:ok, response} = Task.await(task)\n```","ref":"readme.html#asynchronous-sending"},{"type":"extras","title":"Error Handling - Poodle Elixir SDK","doc":"```elixir\ncase Poodle.send_html(from, to, subject, html) do\n  {:ok, response} ->\n    IO.puts(\"Email sent! Message: #{response.message}\")\n\n    # Check rate limit info\n    if response.rate_limit do\n      IO.puts(\"Rate limit remaining: #{response.rate_limit.remaining}\")\n    end\n\n  {:error, %Poodle.Error{type: :unauthorized}} ->\n    IO.puts(\"Invalid API key\")\n\n  {:error, %Poodle.Error{type: :rate_limit_exceeded, retry_after: retry_after}} ->\n    IO.puts(\"Rate limited. Retry after #{retry_after} seconds\")\n\n  {:error, %Poodle.Error{type: :validation_error, message: message}} ->\n    IO.puts(\"Validation error: #{message}\")\n\n  {:error, %Poodle.Error{type: :payment_required}} ->\n    IO.puts(\"Subscription expired or limit reached\")\n\n  {:error, error} ->\n    IO.puts(\"Error: #{error.message}\")\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"API Reference - Poodle Elixir SDK","doc":"","ref":"readme.html#api-reference"},{"type":"extras","title":"Main Functions - Poodle Elixir SDK","doc":"- `Poodle.send/4` - Send email with HTML and/or text content\n- `Poodle.send_html/5` - Send HTML email\n- `Poodle.send_text/5` - Send plain text email\n- `Poodle.send_email/3` - Send email using Email struct\n- `Poodle.send_async/4` - Send email asynchronously\n- `Poodle.validate_config/1` - Validate configuration","ref":"readme.html#main-functions"},{"type":"extras","title":"Data Structures - Poodle Elixir SDK","doc":"#### Email Struct\n\n```elixir\n%Poodle.Email{\n  from: \"sender@example.com\",\n  to: \"recipient@example.com\",\n  subject: \"Email Subject\",\n  html: \" HTML content \",  # optional\n  text: \"Plain text content\"      # optional\n}\n```\n\n#### Response Struct\n\n```elixir\n%Poodle.Response{\n  success: true,\n  message: \"Email queued for sending\",\n  rate_limit: %Poodle.RateLimit{\n    limit: 2,\n    remaining: 1,\n    reset: 1640995200\n  }\n}\n```\n\n#### Error Struct\n\n```elixir\n%Poodle.Error{\n  type: :rate_limit_exceeded,\n  message: \"Rate limit exceeded\",\n  status_code: 429,\n  retry_after: 30,\n  details: %{...}\n}\n```","ref":"readme.html#data-structures"},{"type":"extras","title":"Error Types - Poodle Elixir SDK","doc":"The SDK provides specific error types for different scenarios:\n\n- `:validation_error` - Invalid input data\n- `:unauthorized` - Invalid or missing API key\n- `:forbidden` - Account suspended\n- `:payment_required` - Subscription issues\n- `:rate_limit_exceeded` - Rate limit exceeded\n- `:server_error` - Server-side errors\n- `:network_error` - Network connectivity issues\n- `:timeout` - Request timeout\n- `:dns_error` - DNS resolution failed\n- `:ssl_error` - SSL/TLS errors","ref":"readme.html#error-types"},{"type":"extras","title":"Phoenix Integration - Poodle Elixir SDK","doc":"","ref":"readme.html#phoenix-integration"},{"type":"extras","title":"In a Phoenix Controller - Poodle Elixir SDK","doc":"```elixir\ndefmodule MyAppWeb.EmailController do\n  use MyAppWeb, :controller\n\n  def send_welcome(conn, %{\"email\" => email, \"name\" => name}) do\n    case Poodle.send_html(\n      \"welcome@myapp.com\",\n      email,\n      \"Welcome, #{name}!\",\n      render_welcome_email(name)\n    ) do\n      {:ok, _response} ->\n        json(conn, %{success: true, message: \"Welcome email sent\"})\n\n      {:error, error} ->\n        conn\n        |> put_status(:unprocessable_entity)\n        |> json(%{success: false, error: error.message})\n    end\n  end\n\n  defp render_welcome_email(name) do\n    \"\"\"\n     Welcome, #{name}! \n     Thank you for joining our service. \n    \"\"\"\n  end\nend\n```","ref":"readme.html#in-a-phoenix-controller"},{"type":"extras","title":"Background Jobs with Oban - Poodle Elixir SDK","doc":"```elixir\ndefmodule MyApp.Workers.EmailWorker do\n  use Oban.Worker, queue: :emails\n\n  @impl Oban.Worker\n  def perform(%Oban.Job{args: %{\"type\" => \"welcome\", \"email\" => email, \"name\" => name}}) do\n    case Poodle.send_html(\n      \"welcome@myapp.com\",\n      email,\n      \"Welcome, #{name}!\",\n      render_welcome_email(name)\n    ) do\n      {:ok, _response} -> :ok\n      {:error, _error} -> {:error, \"Failed to send email\"}\n    end\n  end\n\n  defp render_welcome_email(name) do\n    \"\"\"\n     Welcome, #{name}! \n     Thank you for joining our service. \n    \"\"\"\n  end\nend\n```","ref":"readme.html#background-jobs-with-oban"},{"type":"extras","title":"Development - Poodle Elixir SDK","doc":"","ref":"readme.html#development"},{"type":"extras","title":"Running Tests - Poodle Elixir SDK","doc":"```bash\n# Set test environment variables\nexport POODLE_API_KEY=test_api_key\n\n# Run tests\nmix test\n\n# Run tests with coverage\nmix test --cover\n```","ref":"readme.html#running-tests"},{"type":"extras","title":"Code Quality - Poodle Elixir SDK","doc":"```bash\n# Format code\nmix format\n\n# Run Credo\nmix credo\n\n# Run Dialyzer\nmix dialyzer\n```","ref":"readme.html#code-quality"},{"type":"extras","title":"Contributing - Poodle Elixir SDK","doc":"Contributions are welcome! Please read our [Contributing Guide](CONTRIBUTING.md) for details on the process for submitting pull requests and our [Code of Conduct](CODE_OF_CONDUCT.md).","ref":"readme.html#contributing"},{"type":"extras","title":"License - Poodle Elixir SDK","doc":"This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}